==> phpicalendar-2.1p0.tgz: phpicalendar/languages/french.inc.php <==
<?php

// French language include
// For version 2.0 PHP iCalendar
//
// Translation by Einbert (einbert@einbert.net)
// And some sentences form version 1.0 made by La Shampouineuse (info@lashampoo.com)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Jour';
$lang['l_week'] 			= 'Semaine';
$lang['l_month'] 			= 'Mois';
$lang['l_year'] 			= 'Ann&eacute;e';
$lang['l_calendar'] 		= 'Calendrier';
$lang['l_next_day'] 		= 'Jour suivant';
$lang['l_next_month'] 		= 'Mois suivant';
$lang['l_next_week'] 		= 'Semaine suivante';
$lang['l_next_year'] 		= 'Ann&eacute;e suivante';
$lang['l_last_day'] 		= 'Jour pr&eacute;c&eacute;dent';
$lang['l_last_month'] 		= 'Mois pr&eacute;c&eacute;dent';
$lang['l_last_week'] 		= 'Semaine pr&eacute;c&eacute;dente';
$lang['l_last_year'] 		= 'Ann&eacute;e pr&eacute;c&eacute;dente';
$lang['l_subscribe'] 		= 'Souscrire';
$lang['l_download'] 		= 'T&eacute;l&eacute;charger';
$lang['l_powered_by'] 		= 'Produit avec';
$lang['l_event'] 			= 'Ev&eacute;nement';
$lang['l_event_start'] 		= 'D&eacute;but';
$lang['l_event_end'] 		= 'Fin';
$lang['l_this_months'] 		= 'Ev&eacute;nements de ce mois';
$lang['l_date'] 			= 'Date';
$lang['l_summary'] 			= 'R&eacute;sum&eacute;';
$lang['l_all_day'] 			= 'Ev&eacute;nements de ce jour';
$lang['l_notes'] 			= 'Notes';
$lang['l_this_years'] 		= 'Ev&eacute;nements de cette ann&eacute;e';
$lang['l_today'] 			= 'Aujourd\'hui';
$lang['l_this_week'] 		= 'Cette semaine';
$lang['l_this_month'] 		= 'Ce mois';
$lang['l_jump'] 			= 'Voir';
$lang['l_tomorrows'] 		= 'Ev&eacute;nement de demain';
$lang['l_goday'] 			= 'Voir aujourd\'hui';
$lang['l_goweek'] 			= 'Voir cette semaine';
$lang['l_gomonth'] 			= 'Voir ce mois';
$lang['l_goyear'] 			= 'Voir cette ann&eacute;e';
$lang['l_search'] 			= 'Rechercher'; // the verb
$lang['l_results'] 			= 'R&eacute;sultats de la recherche';
$lang['l_query'] 			= 'Requ&egrave;te'; // will be followed by the search query
$lang['l_no_results'] 		= 'Aucun &eacute;v&eacute;nement trouv&eacute;';
$lang['l_goprint'] 			= 'Version imprimable';
$lang['l_time'] 			= 'Heure';
$lang['l_summary'] 			= 'R&eacute;sum&eacute;';
$lang['l_description'] 		= 'Description';
$lang['l_this_site_is']		= 'Ce site est';
$lang['l_no_events_day']	= 'Pas d\'&eacute;v&eacute;nements aujourd\'hui.';
$lang['l_no_events_week']	= 'Pas d\'&eacute;v&eacute;nements cette semaine.';
$lang['l_no_events_month']	= 'Pas d\'&eacute;v&eacute;nements ce mois.';
$lang['l_rss_day_date']		= 'H:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_language']		= 'fr-fr';
$lang['l_search_took']		= 'La recherche a pris %s seconds';
$lang['l_recurring_event']	= 'Ev&eacute;nement r&eacute;curent';
$lang['l_exception']		= 'Exception';
$lang['l_no_query']			= 'Aucune requ&egrave;te';
$lang['l_preferences']		= 'Pr&eacute;f&eacute;rences';
$lang['l_printer']			= 'Imprimante';
$lang['l_select_lang']		= 'Choisissez votre langage par d&eacute;faut';
$lang['l_select_cal']		= 'Choisissez votre calendrier par d&eacute;faut';
$lang['l_select_view']		= 'Choisissez votre vue par d&eacute;faut';
$lang['l_select_time']		= 'Choisissez votre heure de d&eacute;but par d&eacute;faut';
$lang['l_select_day']		= 'Choisissez votre jour de d&eacute;but de semaine par d&eacute;faut';
$lang['l_select_style']		= 'Choisissez votre style par d&eacute;faut';
$lang['l_set_prefs']		= 'Enregistrer les pr&eacute;f&eacute;rences';
$lang['l_completed_date']	= 'Termin&eacute; le';
$lang['l_completed']		= 'Termin&eacute;';
$lang['l_created']			= 'Cr&eacute;&eacute;';
$lang['l_due']				= 'Fin:';
$lang['l_priority']			= 'Priorit&eacute;';
$lang['l_priority_high']	= 'Haute';
$lang['l_priority_low']		= 'Basse';
$lang['l_priority_medium']	= 'Moyenne';
$lang['l_priority_none']	= 'Aucune';
$lang['l_status']			= 'Status:';
$lang['l_todo']				= 'T&acirc;ches &agrave; r&eacute;aliser';
$lang['l_unfinished']		= 'Non faites';
$lang['l_prefs_set'] 		= 'Vos pr&eacute;f&eacute;rences ont &eacute;t&eacute; modifi&eacute;es.';
$lang['l_prefs_unset'] 		= 'Pr&eacute;f&eacute;rences supprim&eacute;es. Changement au prochain chargement de la page.';
$lang['l_unset_prefs'] 		= 'Supprimez les pr&eacute;f&eacute;rences';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_status']			= 'Status';
$lang['l_location']			= 'Location';
$lang['l_admin_header']		= 'Administration de PHP iCalendar';
$lang['l_username']			= 'Utilisateur';
$lang['l_password']			= 'Mot de passe';
$lang['l_login']			= 'Authentification';
$lang['l_invalid_login']	= 'Utilisateur ou mot de passe erron&eacute;.';
$lang['l_addupdate_cal']	= 'Ajoutez ou modifiez un calendrier';
$lang['l_addupdate_desc']	= 'Ajoutez un calendrier en chargeant un nouveau fichier. Modifiez un calendrier en chargeant un fichier de m&ecirc;me nom.';
$lang['l_delete_cal']		= 'Effacez un calendrier';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Fichier calendrier';
$lang['l_php_error']		= 'Erreur PHP';
$upload_error_gen_lang		= 'Une erreur lors du t&eacute;l&eacute;chargement s\'est produite.';
$upload_error_lang[0]		= 'Une erreur lors du t&eacute;l&eacute;chargement s\'est produite.';
$upload_error_lang[1]		= 'Le fichier que vous tentez de t&eacute;l&eacute;charger est trop grand.';
$upload_error_lang[2]		= 'Le fichier que vous tentez de t&eacute;l&eacute;charger est trop grand.';
$upload_error_lang[3]		= 'Le fichier n\'a &eacute;t&eacute; que partiellement t&eacute;l&eacute;charg&eacute;.';
$upload_error_lang[4]		= 'Vous devez choisir un fichier &agrave; t&eacute;l&eacute;charger.';
$lang['l_upload_error_type'] = 'Seuls des fichiers au format .ics peuvent &ecirc;tre t&eacute;l&eacute;charg&eacute;s.';
$lang['l_copy_error']			= 'La copie du fichier a &eacute;chou&eacute;';
$lang['l_delete_error']			= 'La suppression du fichier a &eacute;chou&eacute;';
$lang['l_delete_success']		= 'a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s.';
$lang['l_action_success']		= 'Action effectu&eacute;e avec succ&egrave;s.';
$lang['l_submit']				= 'Envoyer';
$lang['l_delete']				= 'Supprimer';
$all_cal_comb_lang			= 'Tous les calendriers';

// New for 2.0
$lang['l_legend']			= 'L&eacute;gende';
$lang['l_admin_subhead']	= 'Contr&ocirc;lez vos calendriers &agrave; partir de cette page';
$lang['l_prefs_subhead']	= 'Stock un cookie pour la visite de ce site';
$lang['l_rss_info']			= 'Information RSS';
$lang['l_rss_subhead']		= 'RSS feeds basic disponible pour chaque calendrier';
$lang['l_rss_notenabled']	= 'RSS n\'est pas disponible sur ce site';

// - navigation
$lang['l_back'] 		= 'Retour';
$lang['l_next'] 		= 'Suivant';
$lang['l_prev'] 		= 'Pr&eacute;c&eacute;dent';
$lang['l_day_view'] 	= 'Vue Journali&egrave;re';
$lang['l_week_view'] 	= 'Vue Hebdomadaire';
$lang['l_month_view'] 	= 'Vue Mensuelle';
$lang['l_year_view'] 	= 'Vue annuelle';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('an','ans');		// for these, put singular
$format_recur_lang['monthly']		= array('mois','mois');		// and plural forms
$format_recur_lang['weekly']		= array('semaine','semaines');		// these will be %freq%
$format_recur_lang['daily']			= array('jour','jours');			// in the replacement below
$format_recur_lang['hourly']		= array('heure','heures');
$format_recur_lang['minutely']		= array('minutes','minutes');
$format_recur_lang['secondly']		= array('seconde','secondes');

$format_recur_lang['start']			= 'Tou(te)s %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'jusqu\'au %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'pendant %int%';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Aux mois: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'Aux dates: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Aux jours: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Dimanche','Lundi','Mardi','Mercredi','Jeudi','Vendredi','Samedi');
$daysofweekshort_lang		= array ('Dim','Lun','Mar','Mer','Jeu','Ven','Sam');
$daysofweekreallyshort_lang	= array ('D','L','M','M','J','V','S');
$monthsofyear_lang			= array ('Janvier','F&eacute;vrier','Mars','Avril','Mai','Juin','Juillet','Ao&ucirc;t','Septembre','Octobre','Novembre','D&eacute;cembre');
$monthsofyearshort_lang		= array ('Jan','F&eacute;v','Mar','Avr','Mai','Juin','Juil','Ao&ucirc;t','Sep','Oct','Nov','D&eacute;c');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'H:i';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%A %e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A %e %B';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Erreur!';
$lang['l_error_window'] 		= 'Une erreur s\'est produite!';
$lang['l_error_calendar'] 		= 'Une erreur s\'est produite lors du traitement du calendrier "%s".';
$lang['l_error_path'] 			= 'Impossible d\'ouvrir le chemin: "%s"';
$lang['l_error_back'] 			= 'Veuillez utiliser le bouton "Retour" pour revenir en arri&egrave;re.';
$lang['l_error_remotecal'] 		= 'Ce serveur refuse les calendriers distants non approuv&eacute;s.';
$lang['l_error_restrictedcal'] 	= 'Vous avez essay&eacute; d\'utiliser un calendrier dont les permissions sont restreintes sur ce serveur.';
$lang['l_error_invalidcal'] 	= 'Fichier calendrier invalide. Veuillez essayer un calendrier diff&eacute;rent.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';

?>

==> phpicalendar-2.31.tgz: phpicalendar/languages/french.inc.php <==
<?php

// French language include
// For version 2.0 PHP iCalendar
//
// Translation by Einbert (einbert@einbert.net)
// And some sentences form version 1.0 made by La Shampouineuse (info@lashampoo.com)
//
// Submit new translations to chad@chadsdomain.com

$lang['l_day'] 				= 'Jour';
$lang['l_week'] 			= 'Semaine';
$lang['l_month'] 			= 'Mois';
$lang['l_year'] 			= 'Ann&eacute;e';
$lang['l_calendar'] 		= 'Calendrier';
$lang['l_next_day'] 		= 'Jour suivant';
$lang['l_next_month'] 		= 'Mois suivant';
$lang['l_next_week'] 		= 'Semaine suivante';
$lang['l_next_year'] 		= 'Ann&eacute;e suivante';
$lang['l_last_day'] 		= 'Jour pr&eacute;c&eacute;dent';
$lang['l_last_month'] 		= 'Mois pr&eacute;c&eacute;dent';
$lang['l_last_week'] 		= 'Semaine pr&eacute;c&eacute;dente';
$lang['l_last_year'] 		= 'Ann&eacute;e pr&eacute;c&eacute;dente';
$lang['l_subscribe'] 		= 'Souscrire';
$lang['l_download'] 		= 'T&eacute;l&eacute;charger';
$lang['l_powered_by'] 		= 'Produit avec';
$lang['l_event'] 			= 'Ev&eacute;nement';
$lang['l_event_start'] 		= 'D&eacute;but';
$lang['l_event_end'] 		= 'Fin';
$lang['l_this_months'] 		= 'Ev&eacute;nements de ce mois';
$lang['l_date'] 			= 'Date';
$lang['l_summary'] 			= 'R&eacute;sum&eacute;';
$lang['l_all_day'] 			= 'Ev&eacute;nements de ce jour';
$lang['l_notes'] 			= 'Notes';
$lang['l_this_years'] 		= 'Ev&eacute;nements de cette ann&eacute;e';
$lang['l_today'] 			= 'Aujourd\'hui';
$lang['l_this_week'] 		= 'Cette semaine';
$lang['l_this_month'] 		= 'Ce mois';
$lang['l_jump'] 			= 'Voir';
$lang['l_tomorrows'] 		= 'Ev&eacute;nement de demain';
$lang['l_goday'] 			= 'Voir aujourd\'hui';
$lang['l_goweek'] 			= 'Voir cette semaine';
$lang['l_gomonth'] 			= 'Voir ce mois';
$lang['l_goyear'] 			= 'Voir cette ann&eacute;e';
$lang['l_search'] 			= 'Rechercher'; // the verb
$lang['l_results'] 			= 'R&eacute;sultats de la recherche';
$lang['l_pick_multiple'] 	= 'Choix multiple';
$lang['l_query'] 			= 'Requ&egrave;te'; // will be followed by the search query
$lang['l_no_results'] 		= 'Aucun &eacute;v&eacute;nement trouv&eacute;';
$lang['l_goprint'] 			= 'Version imprimable';
$lang['l_time'] 			= 'Heure';
$lang['l_summary'] 			= 'R&eacute;sum&eacute;';
$lang['l_description'] 		= 'Description';
$lang['l_this_site_is']		= 'Ce site est';
$lang['l_no_events_day']	= 'Pas d\'&eacute;v&eacute;nements aujourd\'hui.';
$lang['l_no_events_week']	= 'Pas d\'&eacute;v&eacute;nements cette semaine.';
$lang['l_no_events_month']	= 'Pas d\'&eacute;v&eacute;nements ce mois.';
$lang['l_rss_day_date']		= 'H:i';  // Lists just the time
$lang['l_rss_week_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_month_date	']	= '%e %b';  // Lists just the day
$lang['l_rss_language']		= 'fr-fr';
$lang['l_search_took']		= 'La recherche a pris %s seconds';
$lang['l_recurring_event']	= 'Ev&eacute;nement r&eacute;curent';
$lang['l_exception']		= 'Exception';
$lang['l_no_query']			= 'Aucune requ&egrave;te';
$lang['l_preferences']		= 'Pr&eacute;f&eacute;rences';
$lang['l_printer']			= 'Imprimante';
$lang['l_select_lang']		= 'Choisissez votre langage par d&eacute;faut';
$lang['l_select_cal']		= 'Choisissez votre calendrier par d&eacute;faut';
$lang['l_select_view']		= 'Choisissez votre vue par d&eacute;faut';
$lang['l_select_time']		= 'Choisissez votre heure de d&eacute;but par d&eacute;faut';
$lang['l_select_day']		= 'Choisissez votre jour de d&eacute;but de semaine par d&eacute;faut';
$lang['l_select_style']		= 'Choisissez votre style par d&eacute;faut';
$lang['l_set_prefs']		= 'Enregistrer les pr&eacute;f&eacute;rences';
$lang['l_completed_date']	= 'Termin&eacute; le';
$lang['l_completed']		= 'Termin&eacute;';
$lang['l_created']			= 'Cr&eacute;&eacute;';
$lang['l_due']				= 'Fin:';
$lang['l_priority']			= 'Priorit&eacute;';
$lang['l_priority_high']	= 'Haute';
$lang['l_priority_low']		= 'Basse';
$lang['l_priority_medium']	= 'Moyenne';
$lang['l_priority_none']	= 'Aucune';
$lang['l_status']			= 'Status:';
$lang['l_status_confirmed'] = 'CONFIRMED' ; 
$lang['l_status_cancelled'] = 'CANCELLED'; 
$lang['l_status_tentative'] = 'TENTATIVE'; 
$lang['l_todo']				= 'T&acirc;ches &agrave; r&eacute;aliser';
$lang['l_unfinished']		= 'Non faites';
$lang['l_prefs_set'] 		= 'Vos pr&eacute;f&eacute;rences ont &eacute;t&eacute; modifi&eacute;es.';
$lang['l_prefs_unset'] 		= 'Pr&eacute;f&eacute;rences supprim&eacute;es. Changement au prochain chargement de la page.';
$lang['l_unset_prefs'] 		= 'Supprimez les pr&eacute;f&eacute;rences';
$lang['l_organizer']		= 'Organizer';
$lang['l_attendee']			= 'Attendee';
$lang['l_status']			= 'Status';
$lang['l_location']			= 'Location';
$lang['l_admin_header']		= 'Administration de PHP iCalendar';
$lang['l_username']			= 'Utilisateur';
$lang['l_password']			= 'Mot de passe';
$lang['l_login']			= 'Authentification';
$lang['l_invalid_login']	= 'Utilisateur ou mot de passe erron&eacute;.';
$lang['l_addupdate_cal']	= 'Ajoutez ou modifiez un calendrier';
$lang['l_addupdate_desc']	= 'Ajoutez un calendrier en chargeant un nouveau fichier. Modifiez un calendrier en chargeant un fichier de m&ecirc;me nom.';
$lang['l_delete_cal']		= 'Effacez un calendrier';
$lang['l_logout']			= 'Logout';
$lang['l_cal_file']			= 'Fichier calendrier';
$lang['l_php_error']		= 'Erreur PHP';
$upload_error_gen_lang		= 'Une erreur lors du t&eacute;l&eacute;chargement s\'est produite.';
$upload_error_lang[0]		= 'Une erreur lors du t&eacute;l&eacute;chargement s\'est produite.';
$upload_error_lang[1]		= 'Le fichier que vous tentez de t&eacute;l&eacute;charger est trop grand.';
$upload_error_lang[2]		= 'Le fichier que vous tentez de t&eacute;l&eacute;charger est trop grand.';
$upload_error_lang[3]		= 'Le fichier n\'a &eacute;t&eacute; que partiellement t&eacute;l&eacute;charg&eacute;.';
$upload_error_lang[4]		= 'Vous devez choisir un fichier &agrave; t&eacute;l&eacute;charger.';
$lang['l_upload_error_type'] = 'Seuls des fichiers au format .ics peuvent &ecirc;tre t&eacute;l&eacute;charg&eacute;s.';
$lang['l_copy_error']			= 'La copie du fichier a &eacute;chou&eacute;';
$lang['l_delete_error']			= 'La suppression du fichier a &eacute;chou&eacute;';
$lang['l_delete_success']		= 'a &eacute;t&eacute; supprim&eacute; avec succ&egrave;s.';
$lang['l_action_success']		= 'Action effectu&eacute;e avec succ&egrave;s.';
$lang['l_submit']				= 'Envoyer';
$lang['l_delete']				= 'Supprimer';
$all_cal_comb_lang			= 'Tous les calendriers';

// New for 2.0
$lang['l_legend']			= 'L&eacute;gende';
$lang['l_admin_subhead']	= 'Contr&ocirc;lez vos calendriers &agrave; partir de cette page';
$lang['l_prefs_subhead']	= 'Stock un cookie pour la visite de ce site';
$lang['l_rss_info']			= 'Information RSS';
$lang['l_rss_subhead']		= 'RSS feeds basic disponible pour chaque calendrier';
$lang['l_rss_notenabled']	= 'RSS n\'est pas disponible sur ce site';

// - navigation
$lang['l_back'] 		= 'Retour';
$lang['l_next'] 		= 'Suivant';
$lang['l_prev'] 		= 'Pr&eacute;c&eacute;dent';
$lang['l_day_view'] 	= 'Vue Journali&egrave;re';
$lang['l_week_view'] 	= 'Vue Hebdomadaire';
$lang['l_month_view'] 	= 'Vue Mensuelle';
$lang['l_year_view'] 	= 'Vue annuelle';

// ---------------------------------


// $format_recur, items enclosed in % will be substituted with variables
$format_recur_lang['delimiter']	= ', ';								// ie, 'one, two, three'

$format_recur_lang['yearly']		= array('an','ans');		// for these, put singular
$format_recur_lang['monthly']		= array('mois','mois');		// and plural forms
$format_recur_lang['weekly']		= array('semaine','semaines');		// these will be %freq%
$format_recur_lang['daily']			= array('jour','jours');			// in the replacement below
$format_recur_lang['hourly']		= array('heure','heures');
$format_recur_lang['minutely']		= array('minutes','minutes');
$format_recur_lang['secondly']		= array('seconde','secondes');

$format_recur_lang['start']			= 'Tou(te)s %int% %freq% %for%';	// ie, 'Every 1 day until January 4' or 'Every 1 day for a count of 5'
$format_recur_lang['until']			= 'jusqu\'au %date%';				// ie, 'until January 4'
$format_recur_lang['count']			= 'pendant %int%';		// ie, 'for 5 times'

$format_recur_lang['bymonth']		= 'Aux mois: %list%';			// ie, 'In months: January, February, March'
$format_recur_lang['bymonthday']	= 'Aux dates: %list%';			// ie, 'On dates: 1, 2, 3, 4'
$format_recur_lang['byday']			= 'Aux jours: %list%';			// ie, 'On days: Mon, Tues, Wed, Thurs'

// ---------------------------------

$daysofweek_lang			= array ('Dimanche','Lundi','Mardi','Mercredi','Jeudi','Vendredi','Samedi');
$daysofweekshort_lang		= array ('Dim','Lun','Mar','Mer','Jeu','Ven','Sam');
$daysofweekreallyshort_lang	= array ('D','L','M','M','J','V','S');
$monthsofyear_lang			= array ('Janvier','F&eacute;vrier','Mars','Avril','Mai','Juin','Juillet','Ao&ucirc;t','Septembre','Octobre','Novembre','D&eacute;cembre');
$monthsofyearshort_lang		= array ('Jan','F&eacute;v','Mar','Avr','Mai','Juin','Juil','Ao&ucirc;t','Sep','Oct','Nov','D&eacute;c');

// For time formatting, check out: http://www.php.net/manual/en/function.date.php
$timeFormat = 'H:i';
$timeFormat_small = 'g:i';

// For date formatting, see note below
$dateFormat_day = '%A %e %B';
$dateFormat_week = '%e %B';
$dateFormat_week_list = '%a %e %b';
$dateFormat_week_jump = '%e %b';
$dateFormat_month = '%B %Y';
$dateFormat_month_list = '%A %e %B';
$dateFormat_year = '%Y';

/*
Notes about dateFormat_*
	The pieces are similar to that of the PHP function strftime(), 
	however only the following is supported at this time:
	
	%A - the full week day name as specified in $daysofweek_lang
	%a - the shortened week day name as specified in $daysofweekshort_lang
	%B - the full month name as specified in $monthsofyear_lang
	%b - the shortened month name as specified in $monthsofyearshort_lang
	%e - the day of the month as a decimal number (1 to 31)
	%Y - the 4-digit year

	If this causes problems with representing your language accurately, let
	us know. We will be happy to modify this if needed.
*/

// Error messages - %s will be replaced with a variable
$lang['l_error_title'] 			= 'Erreur!';
$lang['l_error_window'] 		= 'Une erreur s\'est produite!';
$lang['l_error_calendar'] 		= 'Une erreur s\'est produite lors du traitement du calendrier "%s".';
$lang['l_error_path'] 			= 'Impossible d\'ouvrir le chemin: "%s"';
$lang['l_error_back'] 			= 'Veuillez utiliser le bouton "Retour" pour revenir en arri&egrave;re.';
$lang['l_error_remotecal'] 		= 'Ce serveur refuse les calendriers distants non approuv&eacute;s.';
$lang['l_error_restrictedcal'] 	= 'Vous avez essay&eacute; d\'utiliser un calendrier dont les permissions sont restreintes sur ce serveur.';
$lang['l_error_invalidcal'] 	= 'Fichier calendrier invalide. Veuillez essayer un calendrier diff&eacute;rent.';
$lang['l_error_cantopen'] 		= 'Unable to open calendar.';
$lang['l_error_cache']			= 'Unable to write to cache directory. Please check your config.';

?>
